/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.asset.auto.tagger;

import com.liferay.asset.kernel.model.AssetEntry;
import com.liferay.portal.kernel.exception.PortalException;

/**
 * Facade to the auto-tagging framework.
 *
 * @author Alejandro Tardín
 */
public interface AssetAutoTagger {

	/**
	 * Automatically applies tags to an asset entry by running every {@link
	 * AssetAutoTagProvider} implementation that can handle the asset entry's
	 * associated model and merging all the resulting tags.
	 *
	 * <p>
	 * Only assets with an associated {@link
	 * com.liferay.asset.kernel.model.AssetRenderer} are supported.
	 * </p>
	 *
	 * @param  assetEntry the asset entry to tag
	 * @throws PortalException if a portal exception occurred
	 */
	public void tag(AssetEntry assetEntry) throws PortalException;

	/**
	 * Removes the tags that have been automatically applied to the asset entry.
	 * Any tags added externally (e.g., via a human or the asset APIs) are not
	 * removed.
	 *
	 * <p>
	 * This method provides a way to rollback {@link #tag(AssetEntry)}.
	 * </p>
	 *
	 * @param  assetEntry the asset entry to untag
	 * @throws PortalException if a portal exception occurred
	 */
	public void untag(AssetEntry assetEntry) throws PortalException;

}